@@ -8,7 +8,7 @@ import yaml
 import importlib.metadata
 
 from . import context
-from .stores import StoreInterface, read_secret
+from .stores import StoreInterface, read_secret, fill_secret
 
 
 config = {}
@@ -40,6 +40,10 @@ def parse_args(stores):
         "version", help="get secenv version"
     )
 
+    subparsers["secrets"] = subparsers_group.add_parser(
+        "secrets", help="fill secrets in the stores"
+    )
+
     subparsers["contexts"] = subparsers_group.add_parser(
         "contexts", help="list available contexts"
     )
@@ -58,7 +62,11 @@ def parse_args(stores):
     )
 
     for store in stores:
-        type = config["stores"][store]["type"]
+        if "extends" in config["stores"][store]:
+            extended = config["stores"][store]["extends"]
+            type = config["stores"][extended]["type"]
+        else:
+            type = config["stores"][store]["type"]
         subparsers[store] = subparsers_group.add_parser(
             store,
             help=f"query store '{store}' of type '{type}'",
@@ -79,6 +87,16 @@ def find_stores() -> dict[str, StoreInterface]:
 
     for name in config["stores"]:
         infos = config["stores"][name]
+
+        if "extends" in infos:
+            extended = infos["extends"]
+            if extended not in config["stores"]:
+                print("Config error: extended store does not exist:", extended)
+                sys.exit(1)
+            extended_infos = config["stores"][extended]
+            extended_infos.update(infos)
+            infos = extended_infos
+
         try:
             store = importlib.import_module(
                 f".stores.{infos['type']}", package="secenv"
@@ -91,6 +109,26 @@ def find_stores() -> dict[str, StoreInterface]:
     return stores
 
 
+def fill_secrets(stores):
+    for secret_config in config["secrets"]:
+        if "secret" not in secret_config:
+            print("Config error: a secret has no name")
+            continue
+        secret_name = secret_config["secret"]
+
+        if "store" not in secret_config:
+            print(f"Config error: 'store' not found in secret {secret_name}")
+            sys.exit(1)
+
+        if secret_config["store"] not in stores:
+            print(f"Config error: store '{secret_config['store']}' not found")
+            sys.exit(1)
+
+        store = stores[secret_config["store"]]
+        secret = {k: v for k, v in secret_config.items() if k not in ["store"]}
+        fill_secret(store, secret)
+
+
 def gen_context(name, stores) -> dict[str, str]:
     context_config = config["contexts"][name]
     output = {}
@@ -144,7 +182,14 @@ def main():
     # remove empty values and 'type' key
     args = {k: v for k, v in vars(args).items() if k != "type" and v}
 
-    if "context" in sys.argv[1]:
+    if "secrets" in sys.argv[1]:
+        if "secrets" not in config:
+            print("Config error: 'secrets' block is not present")
+            sys.exit(1)
+        fill_secrets(stores)
+        return
+
+    elif "context" in sys.argv[1]:
         if sys.argv[1].endswith("s"):
             # secenv contexts
             print(list_contexts())
