@@ -5,6 +5,7 @@ from .contexts.aws_assume_role import aws_assume_role
 from .stores import read_secret
 from .utils import escape
 
+
 available_formats = ["dotenv", "shell", "github_actions"]
 
 
@@ -14,15 +15,16 @@ def format_output(context, format):
         for k, v in context.items():
             output.append(f"{k}={escape(v['value'])}")
         output = "\n".join(output)
+
     elif format == "shell":
         for k, v in context.items():
             output.append(f"export {k}={escape(v['value'])}")
         output = "\n".join(output)
+
     elif format == "github_actions":
         for k, v in context.items():
             # Here we have to handle the quotes in yet another way
             # as the 'echo' below add some too
-
             if type(v) == str:
                 escaped = escape(v)
             else:
@@ -37,9 +39,11 @@ def format_output(context, format):
                 if type(v) != str and v["sensitive"]:
                     output.append(f'echo "::add-mask::{escaped[1:-1]}"')
         output = "\n".join(output)
+
     else:
         print(f"User error: format {format} not found, available: {available_formats}")
         sys.exit(1)
+
     return str(output)
 
 
@@ -111,4 +115,12 @@ def gen_aws_assume_role(creds, stores):
         print(f"AWS error: couldn't assume role '{creds['role']}'")
         sys.exit(1)
 
-    return output
+    sensitive_output = {}
+
+    for key, value in output.items():
+        sensitive_output[key] = {
+            "value": value,
+            "sensitive": True,
+        }
+
+    return sensitive_output
