@@ -21,3 +21,6 @@ class Store(StoreInterface):
                 f"bitwarden store '{self.name}': rbw error during execution: {stderr}"
             )
         return result.stdout.strip().decode("utf-8")
+
+    def fill_secret(self, secret):
+        raise Exception("Can't write secrets to Bitwarden for now.")
