@@ -1,5 +1,5 @@
 import os
-from . import StoreInterface, cached
+from . import StoreInterface, cached, ask_secret
 
 
 class Store(StoreInterface):
@@ -15,3 +15,6 @@ class Store(StoreInterface):
             return res
         else:
             raise Exception(f"Secret '{secret}' not found in store '{self.name}'")
+
+    def fill_secret(self, secret):
+        os.environ[secret] = ask_secret(self.name, secret)
