@@ -1,6 +1,6 @@
 import hvac
 import hvac.exceptions
-from . import StoreInterface, cached
+from . import StoreInterface, ask_secret, cached
 
 
 class Store(StoreInterface):
@@ -28,3 +28,16 @@ class Store(StoreInterface):
 
     def filter(self, secret, key):
         return secret["data"]["data"][key]
+
+    def fill_secret(self, secret, engine="", keys=[]):
+        if keys:
+            values = {}
+            for key in keys:
+                values[key] = ask_secret(self.name, secret, key)
+            secret_value = values
+        else:
+            secret_value = {secret: ask_secret(self.name, secret)}
+
+        self.client.secrets.kv.create_or_update_secret(
+            path=secret, mount_point=engine, secret=secret_value
+        )
