@@ -26,3 +26,7 @@ def gen_uid(store, secret_def):
 
     # 3) generate the final string used as the unique ID
     return "-".join([store] + filtered_keys)
+
+
+def yes_no(ask):
+    return input(ask + " [yN] ").lower() in ["y", "yes"]
